@@ -14,11 +14,11 @@
 """
 
 from abc import ABC
-from hspylib.core.preconditions import check_argument
-from hspylib.core.tools.text_tools import elide_text, justified_center, justified_left, justified_right
-from typing import List, Optional
+from typing import List
 
-import sys
+from hspylib.core.preconditions import check_argument
+from hspylib.core.tools.commons import sysout
+from hspylib.core.tools.text_tools import elide_text, justified_center, justified_left, justified_right
 
 
 class TableRenderer:
@@ -30,23 +30,25 @@ class TableRenderer:
         Table cell text justification helper.
         """
 
-        LEFT = justified_left
-        CENTER = justified_center
-        RIGHT = justified_right
+        # fmt: off
+        LEFT    = justified_left
+        CENTER  = justified_center
+        RIGHT   = justified_right
+        # fmt: on
 
-    def __init__(self, table_headers: List[str], table_data: Optional[iter], table_caption: str = None):
+    def __init__(self, headers: List[str], data: iter, caption: str | None = None):
         """
-        :param table_headers: table headers to be displayed.
-        :param table_data: table record set with the selected rows.
-        :param table_caption: table caption to be displayed.
+        :param headers: table headers to be displayed.
+        :param data: table record set with the selected rows.
+        :param caption: table caption to be displayed.
         """
 
-        self.headers = table_headers
-        self.rows = table_data if table_data else []
-        self.caption = table_caption
+        self.headers = headers
+        self.rows = data if data else []
+        self.caption = caption
         self.header_alignment = TableRenderer.TextAlignment.CENTER
         self.cell_alignment = TableRenderer.TextAlignment.LEFT
-        self.min_column_size = 6
+        self.min_cell_size = 6
         if self.rows:
             check_argument(
                 len(min(self.rows, key=len)) == len(self.headers),
@@ -54,54 +56,50 @@ class TableRenderer:
                 len(min(self.rows, key=len)),
                 len(self.headers),
             )
-        self.column_sizes = [max(self.min_column_size, len(header)) for header in self.headers]
+        self.column_sizes = [max(self.min_cell_size, len(header)) for header in self.headers]
         self.indexes = range(len(self.column_sizes))
 
     def set_header_alignment(self, alignment: TextAlignment) -> None:
-        """
-        Set table header justification.
+        """Set table headers alignment.
         :param alignment: table header text alignment function.
         :return:
         """
         self.header_alignment = alignment
 
     def set_cell_alignment(self, alignment: TextAlignment) -> None:
-        """
-        Set table header justification.
+        """Set table cell alignment.
         :param alignment: table cell text alignment function.
         :return:
         """
         self.cell_alignment = alignment
 
-    def set_min_column_size(self, size: int) -> None:
-        """
-        Set table header justification.
+    def set_min_cell_size(self, size: int) -> None:
+        """Set the minimum length of a cell.
         :param size: minimum table cell size.
         :return:
         """
-        self.min_column_size = size
+        self.min_cell_size = size
 
-    def adjust_sizes_by_largest_cell(self) -> None:
-        """
-        Render table based on the maximum size of all cell data.
+    def adjust_cells_by_largest(self) -> None:
+        """Adjust cell sizes based on the maximum length of a cell.
         :return: None
         """
         for row in self.rows:
-            for idx, dummy in enumerate(row):
+            for idx, _ in enumerate(row):
                 self.column_sizes[idx] = max(self.column_sizes[idx], len(str(row[idx])))
 
-    def set_fixed_cell_size(self, width: int) -> None:
-        """
-        Render table based on a fixed size for all cell data.
+    def set_fixed_cell_size(self, size: int) -> None:
+        """Adjust cell sizes to a fixed size.
+        :param size: the fixed cell size.
         :return: None
         """
         for row in self.rows:
             for idx in range(0, len(row)):
-                self.column_sizes[idx] = max(width, self.min_column_size)
+                self.column_sizes[idx] = max(size, self.min_cell_size)
 
     def set_cell_sizes(self, cell_sizes: List[int]) -> None:
-        """
-        Render table based on a list of fixed sizes.
+        """Render table based on a list of fixed sizes.
+        :param cell_sizes: TODO
         :return: None
         """
         check_argument(
@@ -112,33 +110,36 @@ class TableRenderer:
         )
         for row in self.rows:
             for idx in range(0, len(row)):
-                self.column_sizes[idx] = max(cell_sizes[idx], self.min_column_size)
+                self.column_sizes[idx] = max(cell_sizes[idx], self.min_cell_size)
 
-    def render(self, file=sys.stdout) -> None:
-        """
-        Render table based on the maximum size of a column header.
-        :param file: a file-like object (stream); defaults to the current sys.stdout.
+    def render(self) -> None:
+        """Render table based on the maximum size of a column header.
         :return: None
         """
         header_cols, data_cols = self._join_header_columns(), self._join_data_columns()
         table_borders = "+" + "".join((("-" * (self.column_sizes[idx] + 2) + "+") for idx in self.indexes))
-        self._print_table(table_borders, header_cols, data_cols, file)
+        self._print_table(table_borders, header_cols, data_cols)
 
     def _join_header_columns(self) -> list:
         """TODO"""
-        cols = [self.header_alignment(self._header_text(idx), self.column_sizes[idx]) for idx in self.indexes]
-        return ["| " + " | ".join(cols) + " |"]
+        # fmt: off
+        return [
+            "| " + " | ".join(
+                [self.header_alignment(self._header_text(idx), self.column_sizes[idx]) for idx in self.indexes]
+            ) + " |"
+        ]
+        # fmt: on
 
-    # pylint: disable=consider-using-f-string
     def _join_data_columns(self) -> list:
         """TODO"""
+        # fmt: off
         return [
-            "| "
-            + "".join(
-                "%s | " % self.cell_alignment(self._cell_text(row, idx), self.column_sizes[idx]) for idx in self.indexes
+            "| " + "".join(
+                f"{self.cell_alignment(self._cell_text(row, idx), self.column_sizes[idx])} | " for idx in self.indexes
             )
             for row in self.rows
         ]
+        # fmt: on
 
     def _header_text(self, idx: int) -> str:
         """TODO"""
@@ -152,19 +153,18 @@ class TableRenderer:
         """TODO"""
         return self.column_sizes[idx]
 
-    def _print_table(self, table_line: str, header_cols: List[str], data_cols: List[str], file=sys.stdout) -> None:
+    def _print_table(self, table_line: str, header_cols: List[str], data_cols: List[str]) -> None:
         """TODO"""
 
+        sysout(table_line.replace("+", "-"))
         if self.caption:
-            print(table_line.replace("+", "-"), file=file)
-            print(
+            sysout(
                 "| " + elide_text(self.caption, len(table_line) - 4).center(len(header_cols[0]) - 4, " ") + " |",
-                file=file,
             )
-        print(f"|{table_line[1:-1]}|", file=file)
-        print("\n".join(header_cols), file=file)
-        print(f"|{table_line[1:-1]}|", file=file)
-        print(
-            "\n".join(data_cols) if data_cols else "| " + "<empty>".center(len(table_line) - 4, " ") + " |", file=file
+            sysout(f"|{table_line[1:-1]}|")
+        sysout("%EOL%".join(header_cols))
+        sysout(f"|{table_line[1:-1]}|")
+        sysout(
+            "%EOL%".join(data_cols) if data_cols else "| " + "<empty>".center(len(table_line) - 4, " ") + " |"
         )
-        print(table_line.replace("+", "-"), file=file)
+        sysout(table_line.replace("+", "-"))
